#ifndef __H1CINTSTEER_H
#define __H1CINTSTEER_H


#include <iostream>
#include <stdio.h>

#include <Api.h>
#include "TString.h"
// Martin Goettlich @ DESY
// 08/10/2004

class H1CintSteer
{
  private:

  public:
  // constructor
// The argument filename is the name of the steering script that should be loaded.
  H1CintSteer(const char* filename);

  // destructor
  virtual ~H1CintSteer();


// Methods to retrieve an int/float/double/TString from the steering script.
// The argument 'name' is the name of the variable that was defined in the 
// steering script and that should be read. If you for example define
// an integer in you steering script by 
// Int_t myvar = 1;
// you can do the following in your executable to get its value 
// (After creating a pointer to an instance of H1CintSteer. It is called steer in this case.): 
// Int_t cut = steer->GetInt("myvar");
  Int_t      GetInt(char* name);
  Float_t    GetFloat(char* name);
  Double_t   GetDouble(char* name);
  TString    GetString(char* name);


// This method allows you to retrieve a variable/object of any type from a steering file.
// It is also used by the above functions GetInt(...), GetFloat(...), GetDouble(...) and GetString(...).
// The first argument is the name of the variable/object that should be read.
// The second argument is the type of variable/object that you want to read. For example type can be:
// "struct TH1F" if you want to get a histogram
// "struct TArrayF" if you want to get an array of floats
// "double" if you want to read a double (of course you can use the method GetDouble(...) to achieve the same.)
// If you want to steer a histogram you define it in the steering-script:
// TH1F hist("myhist","mytitle",50,0,50);
// In your executable you just do (let's assume the name of the steering script is script.C):
// H1CintSteer* steer = new H1CintSteer("script.C");
// TH1F* hist = (TH1F*) steer->GetPtr("hist","struct TH1F");
// The return value is a NULL pointer if the variable is not defined or the types don't match. So
// there is a way to check if the function call was successful.
  void*      GetPtr(char* name, char* type);

// This method allows you to call a function that is defined in the steering script. It is useful if
// you want to call member functions of an object you defined in the steering script.
  void       CallFunction(const char* funcname);


  ClassDef(H1CintSteer,1)
};
#endif
